@@ -50,11 +50,11 @@ calcWdataRaster <- function(w, dataset, fun, missing_pxl){
   if(useNL == FALSE){
     Wdatamatrix <- do.call(cbind,lapply(dataset, function(band){
       wraster <- focal(band, w, fun, na.rm = TRUE, pad = TRUE)
-      return(raster::values(wraster))
+      return(terra::values(wraster, mat = FALSE))
     }))
   }else{
     # step1: creating an array with all the matrices
-    mats <- lapply(dataset, raster::as.matrix)
+    mats <- lapply(dataset, terra::as.matrix)
     arr <- array(do.call(c,mats),c(nrow(mats[[1]]), ncol(mats[[1]]), length(mats)))
     # step2 : getting the lagged version of the array
     arr_lag <- focal_adj_mean_arr_window(arr, w)
@@ -83,7 +83,7 @@ calcWdataRaster <- function(w, dataset, fun, missing_pxl){
 #' # this is an internal function, no example provided
 check_raters_dims <- function(rasters){
   dims <- lapply(rasters, function(i){
-    return(c(raster::nrow(i), raster::ncol(i)))
+    return(c(terra::nrow(i), terra::ncol(i)))
   })
   dims <- do.call(rbind, dims)
   ref <- dims[1,]
@@ -104,33 +104,17 @@ check_raters_dims <- function(rasters){
 #' @param standardize A boolean to specify if the variable must be centered and
 #'   reduced (default = True)
 #' @return A list with the required elements to perform clustering
-#' @importFrom raster focal ncell
+#' @importFrom terra focal ncell
 #' @keywords internal
 #' @examples
 #' # this is an internal function, no example provided
 input_raster_data <- function(dataset, w = NULL, fun = sum, standardize = TRUE){
-
+  #nocov start
   if(is.null(w) == FALSE){
     check_raters_dims(dataset)
     check_window(w)
   }
 
-  #   if(class(fun) != "function"){
-  #     if(fun != "nl"){
-  #       useNL <- FALSE
-  #       tryCatch(fun <- eval(parse(text=fun)),
-  #                error = function(e)
-  #                  print("When using rasters, the parameter lag_method must be a function or a string
-  #                that can be parsed to a function like sum, mean, min, max ...,
-  #                Note that this function is applied to the pixels values multiplied by the weights in the window.
-  #                There is one exception : 'nl_mean', see help(Cmeans).")
-  #       )
-  #     }else{
-  #       useNL <- TRUE
-  #     }
-  #   }
-  # }
-
   refdim <- dim(dataset[[1]])
   for(band in dataset){
     dim2 <- dim(band)
@@ -147,13 +131,13 @@ input_raster_data <- function(dataset, w = NULL, fun = sum, standardize = TRUE){
 
   if(standardize){
     for(i in 1:length(dataset)){
-      dataset[[i]] <- raster::scale(dataset[[i]])
+      dataset[[i]] <- terra::scale(dataset[[i]])
     }
   }
 
   #step1 : prepare the regular dataset
   datamatrix <- do.call(cbind,lapply(dataset, function(band){
-    raster::values(band)
+    terra::values(band, mat = FALSE)
   }))
 
   #step2 : only keep the non-missing valuez
@@ -167,27 +151,6 @@ input_raster_data <- function(dataset, w = NULL, fun = sum, standardize = TRUE){
   #step3 : calculating Wdata if necessary
   if(is.null(w) == FALSE){
     Wdata_class <- calcWdataRaster(w, dataset, fun, missing_pxl)
-    # if(useNL == FALSE){
-    #   Wdatamatrix <- do.call(cbind,lapply(dataset, function(band){
-    #     wraster <- focal(band, w, fun, na.rm = TRUE, pad = TRUE)
-    #     return(raster::values(wraster))
-    #   }))
-    # }else{
-    #   # step1: creating an array with all the matrices
-    #   mats <- lapply(dataset, raster::as.matrix)
-    #   arr <- array(do.call(c,mats),c(nrow(mats[[1]]), ncol(mats[[1]]), length(mats)))
-    #   # step2 : getting the lagged version of the array
-    #   arr_lag <- focal_adj_mean_arr_window(arr, w)
-    #   # step3 : creating the Wdatamatrix
-    #   nsl <- dim(arr_lag)[[3]]
-    #   Wdatamatrix <- do.call(cbind, lapply(1:nsl, function(i){
-    #       vec <- arr_lag[,,i]
-    #       dim(vec) <- NULL
-    #       return(vec)
-    #     })
-    #   )
-    # }
-    # Wdata_class <- Wdatamatrix[missing_pxl,]
     if(is.null(dim(Wdata_class))){
       Wdata_class <- matrix(Wdata_class, ncol = 1)
     }
@@ -203,6 +166,7 @@ input_raster_data <- function(dataset, w = NULL, fun = sum, standardize = TRUE){
               "rst" = dataset[[1]],
               "window" = w
               ))
+  #nocov end
 }
 
 
@@ -219,16 +183,19 @@ input_raster_data <- function(dataset, w = NULL, fun = sum, standardize = TRUE){
 #' @examples
 #' # this is an internal function, no example provided
 output_raster_data <- function(object, missing, rst){
+
+  #nocov start
   # object is created by a FCM like function
   # missing is indicating which pixels are complete
   # rst is a basic raster to duplicate it
+  i <- 1
 
   #step1 : creating a raster for each cluster
   rasters <- lapply(1:ncol(object$Belongings), function(i){
     rst2 <- rst
     vec <- rep(NA,times = ncell(rst))
     vec[missing] <- object$Belongings[,i]
-    raster::values(rst2) <- vec
+    terra::values(rst2) <- vec
     return(rst2)
   })
 
@@ -239,12 +206,22 @@ output_raster_data <- function(object, missing, rst){
   vec <- rep(NA,times = ncell(rst))
   DF <- as.data.frame(object$Belongings)
   vec[missing] <- max.col(DF, ties.method = "first")
-  raster::values(rst2) <- vec
+  terra::values(rst2) <- vec
   rasters[["Groups"]] <- rst2
 
+  #step3 : adding the noise group if needed
+  if(is.null(object$noise_cluster) == FALSE){
+    rst2 <- rst
+    vec <- rep(NA,times = ncell(rst))
+    vec[missing] <- object$noise_cluster[,i]
+    terra::values(rst2) <- vec
+    object$noise_cluster <- rst2
+  }
+
   object$isRaster <- TRUE
   object$rasters <- rasters
   object$missing <- missing
   return(object)
+  #nocov end
 }
 
