@@ -14,7 +14,7 @@ AnalysisFields <-c("Lden","NO2","PM25","VegHautPrt","Pct0_14",
                    "Pct_65","Pct_Img","TxChom1564","Pct_brevet","NivVieMed")
 
 #rescaling the columns
-Data <- LyonIris@data[AnalysisFields]
+Data <- sf::st_drop_geometry(LyonIris[AnalysisFields])
 for (Col in names(Data)){
   Data[[Col]] <- scale(Data[[Col]])
 }
@@ -28,7 +28,7 @@ SFCM <- SFCMeans(Data, WMat, k = 4, m = 1.5, alpha = 0.7,
                  tol = 0.0001, standardize = FALSE,
                  verbose = FALSE, seed = 456)
 
-#calculating the spatial inconsistency index (more replications are recommanded)
+#calculating the spatial inconsistency index (more replications are recommended)
 consistIndex <- spConsistency(SFCM$Belongings, WMat, nrep = 100)
 
 ggplot() + 
